Module buffer

Module buffer 

Structs

AbortInfo
Information associated with a step aborted by the user.
AbortMessageDisplay
Displays the message for an execution abort.
CompletionInfo
Completion information associated with a step.
EventBuffer
A receiver for events that provides a pull-based model with periodic reports.
EventBufferExecutionData
Per-execution data tracked by the event buffer.
EventBufferStepData
Step-related data for a particular key.
EventBufferSteps
An ordered list of steps contained in an event buffer.
ExecutionSummary
ExecutionTerminalInfo
Terminal status about a single execution ID.
FailureInfo
Information about a failed step.
RootEventIndex
A newtype to track root event indexes within EventBuffers, to ensure that we aren’t mixing them with leaf event indexes in this code.
StepKey
A unique identifier for a group of step or progress events.
StepSortKey
Step sort key.

Enums

AbortReason
CompletionReason
ExecutionStatus
Status about a single execution ID.
FailureReason
StepStatus
The step status as last seen by events.
TerminalKind
The way in which an execution was terminated.
WillNotBeRunReason