pub enum CompletionReason {
StepCompleted(Arc<CompletionInfo>),
SubsequentStarted {
later_step: StepKey,
root_total_elapsed: Duration,
},
ParentCompleted {
parent_step: StepKey,
parent_info: Arc<CompletionInfo>,
},
}Variants
StepCompleted(Arc<CompletionInfo>)
This step completed.
SubsequentStarted
A later step within the same execution was started and we don’t have information regarding this step.
Fields
ParentCompleted
A parent step within the same execution completed and we don’t have information regarding this step.
Fields

parent_info: Arc<CompletionInfo>Completion info associated with the parent step.
Implementations
Sourceimpl CompletionReason
impl CompletionReason
Sourcepub fn step_completed_info(&self) -> Option<&Arc<CompletionInfo>>
pub fn step_completed_info(&self) -> Option<&Arc<CompletionInfo>>
Returns the CompletionInfo for this step, if this is the
Self::StepCompleted variant.