ExecutionStatus

Enum ExecutionStatus 

pub enum ExecutionStatus {
    NotStarted,
    Running {
        step_key: StepKey,
        root_total_elapsed: Duration,
    },
    Terminal(ExecutionTerminalInfo),
}
Status about a single execution ID.

Part of ExecutionSummary.

Variants



NotStarted

This execution has not been started yet.



Running

This execution is currently running.

Fields

step_key: StepKey

The step key that’s currently running.

Use super::EventBuffer::get to get more information about this step.

root_total_elapsed: Duration

The maximum root_total_elapsed seen.



Terminal(ExecutionTerminalInfo)

Execution has finished.

Implementations

Source

impl ExecutionStatus

pub fn terminal_info(&self) -> Option<&ExecutionTerminalInfo>

Returns the terminal status and the total amount of time elapsed, or None if the execution has not reached a terminal state.

The time elapsed might be None if the execution was interrupted and completion information wasn’t available.