StepStatus

Enum StepStatus 

pub enum StepStatus<S: EngineSpec> {
    NotStarted,
    Running {
        low_priority: VecDeque<StepEvent<S>>,
        progress_event: ProgressEvent<S>,
    },
    Completed {
        reason: CompletionReason,
    },
    Failed {
        reason: FailureReason,
    },
    Aborted {
        reason: AbortReason,
        last_progress: Option<ProgressEvent<S>>,
    },
    WillNotBeRun {
        reason: WillNotBeRunReason,
    },
}
The step status as last seen by events.

Variants



NotStarted



Running

The step is currently running.

Fields

low_priority: VecDeque<StepEvent<S>>
progress_event: ProgressEvent<S>


Completed

The step has completed execution.

Fields

reason: CompletionReason

The reason for completion.



Failed

The step has failed.

Fields

reason: FailureReason

The reason for the failure.



Aborted

Execution was aborted while this step was running.

Fields

reason: AbortReason

The reason for the abort.

last_progress: Option<ProgressEvent<S>>

The last progress seen, if any.



WillNotBeRun

The step will not be executed because a prior step failed.

Fields

reason: WillNotBeRunReason

The step that failed and caused this step to not be run.

Implementations

Source

impl<S: EngineSpec> StepStatus<S>

pub fn is_running(&self) -> bool

Returns true if this step is currently running.

pub fn completion_reason(&self) -> Option<&CompletionReason>

For completed steps, return the completion reason, otherwise None.

pub fn failure_reason(&self) -> Option<&FailureReason>

For failed steps, return the failure reason, otherwise None.

pub fn abort_reason(&self) -> Option<&AbortReason>

For aborted steps, return the abort reason, otherwise None.

To also obtain the last progress event at the time of the abort, use Self::aborted_with_progress.

pub fn aborted_with_progress( &self, ) -> Option<(&AbortReason, Option<&ProgressEvent<S>>)>

For aborted steps, return the abort reason together with the last progress event (if any), otherwise None.

pub fn will_not_be_run_reason(&self) -> Option<&WillNotBeRunReason>

For will-not-be-run steps, return the reason, otherwise None.

pub fn low_priority(&self) -> impl Iterator<Item = &StepEvent<S>>

Returns low-priority events for this step, if any.

Events are sorted by event index.

pub fn progress_event(&self) -> Option<&ProgressEvent<S>>

Returns the associated progress event for this step, if any.