pub struct CompletionInfo {
pub attempt: usize,
pub outcome: StepOutcome<GenericSpec>,
pub root_total_elapsed: Duration,
pub leaf_total_elapsed: Duration,
pub step_elapsed: Duration,
pub attempt_elapsed: Duration,
}Expand description
Completion information associated with a step.
Fields
attempt: usizeThe attempt number of the step.
outcome: StepOutcome<GenericSpec>The outcome of the step: success, warning, or skipped.
root_total_elapsed: DurationThe total elapsed time as reported by the root event.
leaf_total_elapsed: DurationThe total elapsed time as reported by the leaf execution event, for nested events.
step_elapsed: DurationDuration elapsed for the step.
attempt_elapsed: DurationDuration elapsed for the attempt.