EventBufferSteps

Struct EventBufferSteps 

pub struct EventBufferSteps<'buf, S: EngineSpec> { /* private fields */ }
An ordered list of steps contained in an event buffer.

Returned by EventBuffer::steps.

Implementations

Source

impl<'buf, S: EngineSpec> EventBufferSteps<'buf, S>

pub fn as_slice(&self) -> &[(StepKey, &'buf EventBufferStepData<S>)]

Returns the list of steps in the event buffer.

pub fn summarize(&self) -> IndexMap<ExecutionUuid, ExecutionSummary>

Summarizes the current state of all known executions, keyed by execution ID.

Values are returned as an IndexMap, in order of when execution IDs were first defined.