pub struct ExecutionTerminalInfo {
pub kind: TerminalKind,
pub root_total_elapsed: Option<Duration>,
pub leaf_total_elapsed: Option<Duration>,
pub step_key: StepKey,
}Expand description
Terminal status about a single execution ID.
Part of ExecutionStatus.
Fields
kind: TerminalKindThe way in which this execution reached a terminal state.
root_total_elapsed: Option<Duration>Total elapsed time (root) for this execution.
The total elapsed time may not be available if execution was interrupted and we inferred that it was terminated.
leaf_total_elapsed: Option<Duration>Total elapsed time (leaf) for this execution.
The total elapsed time may not be available if execution was interrupted and we inferred that it was terminated.
step_key: StepKeyThe step key that was running when this execution was terminated.
- For completed executions, this is the last step that completed.
- For failed or aborted executions, this is the step that failed.
- For aborted executions, this is the step that was running when the abort happened.