FailureInfo

Struct FailureInfo 

pub struct FailureInfo {
    pub total_attempts: usize,
    pub message: String,
    pub causes: Vec<String>,
    pub root_total_elapsed: Duration,
    pub leaf_total_elapsed: Duration,
    pub step_elapsed: Duration,
    pub attempt_elapsed: Duration,
}
Information about a failed step.

Fields

total_attempts: usize

The total number of attempts made for this step.

message: String

The failure message.

causes: Vec<String>

Failure causes.

root_total_elapsed: Duration

The total elapsed time as reported by the root event.

leaf_total_elapsed: Duration

The total elapsed time as reported by the leaf execution event, for nested events.

step_elapsed: Duration

Duration elapsed for the step.

attempt_elapsed: Duration

Duration elapsed for the attempt.