pub struct RootEventIndex(pub usize);Expand description
A newtype to track root event indexes within EventBuffers, to ensure
that we aren’t mixing them with leaf event indexes in this code.
Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for RootEventIndex
impl Clone for RootEventIndex
Sourcefn clone(&self) -> RootEventIndex
fn clone(&self) -> RootEventIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RootEventIndex
impl Debug for RootEventIndex
Sourceimpl Display for RootEventIndex
impl Display for RootEventIndex
Sourceimpl Hash for RootEventIndex
impl Hash for RootEventIndex
Sourceimpl Ord for RootEventIndex
impl Ord for RootEventIndex
Sourcefn cmp(&self, other: &RootEventIndex) -> Ordering
fn cmp(&self, other: &RootEventIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RootEventIndex
impl PartialEq for RootEventIndex
Sourceimpl PartialOrd for RootEventIndex
impl PartialOrd for RootEventIndex
impl Copy for RootEventIndex
impl Eq for RootEventIndex
impl StructuralPartialEq for RootEventIndex