Module events

Module events 

Progress, success and failure events generated by the update engine.

Events are serializable. When the schemars08 feature is enabled, they also implement JsonSchema so that they can be transmitted over the wire with schema support.

Structs

EventReport
A report produced from an EventBuffer.
ProgressCounter
Current progress.
ProgressEvent
ProgressUnits
StepComponentSummary
StepEvent
StepInfo
Serializable information about a step.
StepInfoWithMetadata
Serializable information about a step.

Enums

Event
ExecutionUuidKind
Marker type for ExecutionUuid.
ProgressEventKind
StepEventIsTerminal
Whether a StepEvent is a terminal event.
StepEventKind
StepEventPriority
The priority of a StepEvent.
StepOutcome
StepProgress

Type Aliases

ExecutionUuid
A unique identifier for an execution of an update engine.