pub enum Event<S: EngineSpec> {
Step(StepEvent<S>),
Progress(ProgressEvent<S>),
}Variants
Step(StepEvent<S>)
Progress(ProgressEvent<S>)
Implementations
Sourceimpl<S: EngineSpec> Event<S>
impl<S: EngineSpec> Event<S>
Sourcepub fn from_generic(
value: Event<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: Event<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn into_generic(self) -> Event<GenericSpec>
pub fn into_generic(self) -> Event<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.