pub enum ProgressEventKind<S: EngineSpec> {
WaitingForProgress {
step: StepInfoWithMetadata<S>,
attempt: usize,
step_elapsed: Duration,
attempt_elapsed: Duration,
},
Progress {
step: StepInfoWithMetadata<S>,
attempt: usize,
metadata: S::ProgressMetadata,
progress: Option<ProgressCounter>,
step_elapsed: Duration,
attempt_elapsed: Duration,
},
Nested {
step: StepInfoWithMetadata<S>,
attempt: usize,
event: Box<ProgressEvent<GenericSpec>>,
step_elapsed: Duration,
attempt_elapsed: Duration,
},
Unknown,
}Variants
WaitingForProgress
The update engine is waiting for a progress message.
The update engine sends this message immediately after a StepEvent
corresponding to a new step.
Fields
step: StepInfoWithMetadata<S>Information about the step.
Progress
Fields
step: StepInfoWithMetadata<S>Information about the step.
metadata: S::ProgressMetadataMetadata that was returned with progress.
progress: Option<ProgressCounter>Current progress.
Nested
Fields
step: StepInfoWithMetadata<S>Information about the step.
event: Box<ProgressEvent<GenericSpec>>The event that occurred.
Unknown
Future variants that might be unknown.
Implementations
Sourceimpl<S: EngineSpec> ProgressEventKind<S>
impl<S: EngineSpec> ProgressEventKind<S>
Sourcepub fn progress_counter(&self) -> Option<&ProgressCounter>
pub fn progress_counter(&self) -> Option<&ProgressCounter>
Returns the progress counter for this event, if available.
Sourcepub fn leaf_attempt(&self) -> Option<usize>
pub fn leaf_attempt(&self) -> Option<usize>
Returns attempt for the leaf event, recursing into nested events as
necessary.
Returns None for unknown events.
Sourcepub fn leaf_step_elapsed(&self) -> Option<Duration>
pub fn leaf_step_elapsed(&self) -> Option<Duration>
Returns step_elapsed for the leaf event, recursing into nested events
as necessary.
Returns None for unknown events.
Sourcepub fn leaf_attempt_elapsed(&self) -> Option<Duration>
pub fn leaf_attempt_elapsed(&self) -> Option<Duration>
Returns attempt_elapsed for the leaf event, recursing into nested
events as necessary.
Returns None for unknown events.
Sourcepub fn from_generic(
value: ProgressEventKind<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: ProgressEventKind<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn into_generic(self) -> ProgressEventKind<GenericSpec>
pub fn into_generic(self) -> ProgressEventKind<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.