StepEventKind

Enum StepEventKind 

pub enum StepEventKind<S: EngineSpec> {
    NoStepsDefined,
    ExecutionStarted {
        steps: Vec<StepInfo<S>>,
        components: Vec<StepComponentSummary<S>>,
        first_step: StepInfoWithMetadata<S>,
    },
    ProgressReset {
        step: StepInfoWithMetadata<S>,
        attempt: usize,
        metadata: S::ProgressMetadata,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
        message: Cow<'static, str>,
    },
    AttemptRetry {
        step: StepInfoWithMetadata<S>,
        next_attempt: usize,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
        message: Cow<'static, str>,
    },
    StepCompleted {
        step: StepInfoWithMetadata<S>,
        attempt: usize,
        outcome: StepOutcome<S>,
        next_step: StepInfoWithMetadata<S>,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
    },
    ExecutionCompleted {
        last_step: StepInfoWithMetadata<S>,
        last_attempt: usize,
        last_outcome: StepOutcome<S>,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
    },
    ExecutionFailed {
        failed_step: StepInfoWithMetadata<S>,
        total_attempts: usize,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
        message: String,
        causes: Vec<String>,
    },
    ExecutionAborted {
        aborted_step: StepInfoWithMetadata<S>,
        attempt: usize,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
        message: String,
    },
    Nested {
        step: StepInfoWithMetadata<S>,
        attempt: usize,
        event: Box<StepEvent<GenericSpec>>,
        step_elapsed: Duration,
        attempt_elapsed: Duration,
    },
    Unknown,
}

Variants



NoStepsDefined

No steps were defined, and the executor exited without doing anything.

This is a terminal event: it is guaranteed that no more events will be seen after this one.



ExecutionStarted

Execution was started.

This is an initial event – it is always expected to be the first event received from the event stream.

Fields

steps: Vec<StepInfo<S>>

The list of steps that will be executed.

components: Vec<StepComponentSummary<S>>

A list of components, along with the number of items each component has.

first_step: StepInfoWithMetadata<S>

Information about the first step.



ProgressReset

Progress was reset along an attempt, and this attempt is going down a different path.

Fields

step: StepInfoWithMetadata<S>

Information about the step.

attempt: usize

The current attempt number.

metadata: S::ProgressMetadata

Progress-related metadata associated with this attempt.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The amount of time this attempt has taken so far.

message: Cow<'static, str>

A message associated with the reset.



AttemptRetry

An attempt failed and this step is being retried.

Fields

step: StepInfoWithMetadata<S>

Information about the step.

next_attempt: usize

The attempt number for the next attempt.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The amount of time the previous attempt took.

message: Cow<'static, str>

A message associated with the retry.



StepCompleted

A step is complete and the next step has been started.

Fields

step: StepInfoWithMetadata<S>

Information about the step that just completed.

attempt: usize

The attempt number that completed.

outcome: StepOutcome<S>

The outcome of the step.

next_step: StepInfoWithMetadata<S>

The next step that is being started.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The time it took for this attempt to complete.



ExecutionCompleted

Execution is complete.

This is a terminal event: it is guaranteed that no more events will be seen after this one.

Fields

last_step: StepInfoWithMetadata<S>

Information about the last step that completed.

last_attempt: usize

The attempt number that completed.

last_outcome: StepOutcome<S>

The outcome of the last step.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The time it took for this attempt to complete.



ExecutionFailed

Execution failed.

This is a terminal event: it is guaranteed that no more events will be seen after this one.

Fields

failed_step: StepInfoWithMetadata<S>

Information about the step that failed.

total_attempts: usize

The total number of attempts that were performed before the step failed.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The time it took for this attempt to complete.

message: String

A message associated with the failure.

causes: Vec<String>

A chain of causes associated with the failure.



ExecutionAborted

Execution aborted by an external user.

This is a terminal event: it is guaranteed that no more events will be seen after this one.

Fields

aborted_step: StepInfoWithMetadata<S>

Information about the step that was running at the time execution was aborted.

attempt: usize

The attempt that was running at the time the step was aborted.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The time it took for this attempt to complete.

message: String

A message associated with the abort.



Nested

A nested step event occurred.

Fields

step: StepInfoWithMetadata<S>

Information about the step that’s occurring.

attempt: usize

The current attempt number.

event: Box<StepEvent<GenericSpec>>

The event that occurred.

step_elapsed: Duration

Total time elapsed since the start of the step. Includes prior attempts.

attempt_elapsed: Duration

The time it took for this attempt to complete.



Unknown

Future variants that might be unknown.

Implementations

Source

impl<S: EngineSpec> StepEventKind<S>

pub fn is_terminal(&self) -> StepEventIsTerminal

Returns whether this is a terminal step event.

Terminal events guarantee that there are no further events coming from this update engine.

This does not recurse into nested events; those are always non-terminal.

pub fn priority(&self) -> StepEventPriority

Returns the priority of the event.

For more about this, see StepEventPriority.

pub fn from_generic( value: StepEventKind<GenericSpec>, ) -> Result<Self, ConvertGenericError>

Converts a generic version into self.

This version can be used to convert a generic type into a more concrete form.

pub fn into_generic(self) -> StepEventKind<GenericSpec>

Converts self into its generic version.

This version can be used to share data across different kinds of engines.

If any of the data in self fails to serialize to a serde_json::Value, it will be replaced with serde_json::Value::Null. Since serde_json::Value represents an arbitrary JSON value, such data would have failed to serialize anyway.

pub fn step_outcome(&self) -> Option<&StepOutcome<S>>

If this represents a successfully-completed step, returns the outcome.

This does not recurse into nested events.