pub enum StepOutcome<S: EngineSpec> {
Success {
message: Option<Cow<'static, str>>,
metadata: Option<S::CompletionMetadata>,
},
Warning {
message: Cow<'static, str>,
metadata: Option<S::CompletionMetadata>,
},
Skipped {
message: Cow<'static, str>,
metadata: Option<S::SkippedMetadata>,
},
}Variants
Success
The step completed successfully.
Fields
metadata: Option<S::CompletionMetadata>Optional completion metadata associated with the step.
Warning
The step completed with a warning.
Fields
metadata: Option<S::CompletionMetadata>Optional completion metadata associated with the step.
Skipped
The step was skipped with a message.
Implementations
Sourceimpl<S: EngineSpec> StepOutcome<S>
impl<S: EngineSpec> StepOutcome<S>
Sourcepub fn from_generic(
value: StepOutcome<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: StepOutcome<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn completion_metadata(&self) -> Option<&S::CompletionMetadata>
pub fn completion_metadata(&self) -> Option<&S::CompletionMetadata>
If this outcome represents completion, returns the metadata associated with this event.
Returns None if this outcome represents “skipped”.
Sourcepub fn into_generic(self) -> StepOutcome<GenericSpec>
pub fn into_generic(self) -> StepOutcome<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.
Sourcepub fn is_success_or_warning(&self) -> bool
pub fn is_success_or_warning(&self) -> bool
Returns true if the step was successful, including success with warning.
Sourcepub fn is_skipped(&self) -> bool
pub fn is_skipped(&self) -> bool
Returns true if the step was skipped.