StepProgress

Enum StepProgress 

pub enum StepProgress<S: EngineSpec> {
    Progress {
        progress: Option<ProgressCounter>,
        metadata: S::ProgressMetadata,
    },
    Reset {
        metadata: S::ProgressMetadata,
        message: Cow<'static, str>,
    },
    Retry {
        message: Cow<'static, str>,
    },
}

Variants



Progress

A step has progressed.

Fields

progress: Option<ProgressCounter>

Current progress.

metadata: S::ProgressMetadata

Metadata associated with progress.



Reset

Progress was reset: typically, the step failed along one path, and the step is now trying a different path.

For example, downloading from one peer failed and we’ve moved to the next peer.

Fields

metadata: S::ProgressMetadata

Metadata associated with the reset.

message: Cow<'static, str>

A message associated with the reset.



Retry

The step is being retried from the beginning.

Fields

message: Cow<'static, str>

An optional message associated with the retry.

Implementations

Source

impl<S: EngineSpec> StepProgress<S>

pub fn with_current_and_total( current: u64, total: u64, units: impl Into<ProgressUnits>, metadata: S::ProgressMetadata, ) -> Self

Creates a new progress message with current and total values.

pub fn with_current( current: u64, units: impl Into<ProgressUnits>, metadata: S::ProgressMetadata, ) -> Self

Creates a new progress message with a current value.

pub fn progress(metadata: S::ProgressMetadata) -> Self

Creates a new progress message without either current or total values.

pub fn reset( metadata: S::ProgressMetadata, message: impl Into<Cow<'static, str>>, ) -> Self

Creates a new reset message.

pub fn retry(message: impl Into<Cow<'static, str>>) -> Self

Creates a new retry message.