pub struct ProgressEvent<S: EngineSpec> {
pub spec: String,
pub execution_id: ExecutionUuid,
pub total_elapsed: Duration,
pub kind: ProgressEventKind<S>,
}Fields
spec: StringThe specification that this event belongs to.
This is typically the name of the type S for which EngineSpec is
implemented.
This can be used with Self::from_generic to deserialize generic
metadata.
execution_id: ExecutionUuidThe execution ID.
total_elapsed: DurationTotal time elapsed since the start of execution.
kind: ProgressEventKind<S>The kind of event this is.
Implementations
Sourceimpl<S: EngineSpec> ProgressEvent<S>
impl<S: EngineSpec> ProgressEvent<S>
Sourcepub fn from_generic(
value: ProgressEvent<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: ProgressEvent<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn into_generic(self) -> ProgressEvent<GenericSpec>
pub fn into_generic(self) -> ProgressEvent<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.