pub struct StepInfo<S: EngineSpec> {
pub id: S::StepId,
pub component: S::Component,
pub description: Cow<'static, str>,
pub index: usize,
pub component_index: usize,
pub total_component_steps: usize,
}Expand description
Serializable information about a step.
Fields
id: S::StepIdAn identifier for this step.
component: S::ComponentThe component that this step is part of.
description: Cow<'static, str>The description for this step.
index: usizeThe index of the step within all steps to be executed.
component_index: usizeThe index of the step within the component.
total_component_steps: usizeThe total number of steps in this component.
Implementations
Sourceimpl<S: EngineSpec> StepInfo<S>
impl<S: EngineSpec> StepInfo<S>
Sourcepub fn is_last_step_in_component(&self) -> bool
pub fn is_last_step_in_component(&self) -> bool
Returns true if this is the last step in this component.
Sourcepub fn from_generic(
value: StepInfo<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: StepInfo<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn into_generic(self) -> StepInfo<GenericSpec>
pub fn into_generic(self) -> StepInfo<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.