ExecutionUuid

Type Alias ExecutionUuid 

pub type ExecutionUuid = TypedUuid<ExecutionUuidKind>;
A unique identifier for an execution of an update engine.

Each time an UpdateEngine is executed, it is assigned a unique ExecutionUuid.

Aliased Type

pub struct ExecutionUuid { /* private fields */ }