Module spec

Module spec 

Structs

GenericSpec
A fully generic step specification where all metadata is serde_json::Value and errors are SerializableError.
SerializableError
A serializable representation of an error chain.
SerializableErrorSources
The sources of a serializable error as an iterator.

Traits

AsError
Trait that abstracts over concrete errors and anyhow::Error.
EngineSpec
A specification for an UpdateEngine.
JsonSchemaEngineSpecschemars08
A trait that requires and provides JSON Schema information for an EngineSpec.

Functions

merge_anyhow_list
A temporary hack to convert a list of anyhow errors into a single anyhow::Error. If no errors are provided, panic (this should be handled at a higher level).