pub struct GenericSpec(/* private fields */);Expand description
A fully generic step specification where all metadata is
serde_json::Value and errors are SerializableError.
Use this if you don’t care about assigning types to any of the metadata components. This is the lowest-common-denominator type for cross-engine communication.