JsonSchemaEngineSpec

Trait JsonSchemaEngineSpec 

pub trait JsonSchemaEngineSpec: EngineSpec<Component: JsonSchema, StepId: JsonSchema, StepMetadata: JsonSchema, ProgressMetadata: JsonSchema, CompletionMetadata: JsonSchema, SkippedMetadata: JsonSchema> + JsonSchema { }
Available on crate feature schemars08 only.
A trait that requires and provides JSON Schema information for an EngineSpec.

This trait has a blanket implementation. To implement this trait, implement JsonSchema for:

  • the EngineSpec type itself
  • all associated types other than the error type

It is also recommended that you add a rust_type_info method to your EngineSpec implementation to enable automatic replacement in typify and progenitor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors