Structs
- Abort
Info - Information associated with a step aborted by the user.
- Abort
Message Display - Displays the message for an execution abort.
- Completion
Info - Completion information associated with a step.
- Event
Buffer - A receiver for events that provides a pull-based model with periodic reports.
- Event
Buffer Execution Data - Per-execution data tracked by the event buffer.
- Event
Buffer Step Data - Step-related data for a particular key.
- Event
Buffer Steps - An ordered list of steps contained in an event buffer.
- Execution
Summary - Execution
Terminal Info - Terminal status about a single execution ID.
- Failure
Info - Information about a failed step.
- Root
Event Index - A newtype to track root event indexes within
EventBuffers, to ensure that we aren’t mixing them with leaf event indexes in this code. - StepKey
- A unique identifier for a group of step or progress events.
- Step
Sort Key - Step sort key.
Enums
- Abort
Reason - Completion
Reason - Execution
Status - Status about a single execution ID.
- Failure
Reason - Step
Status - The step status as last seen by events.
- Terminal
Kind - The way in which an execution was terminated.
- Will
NotBe RunReason