pub struct EventBufferSteps<'buf, S: EngineSpec> { /* private fields */ }Expand description
An ordered list of steps contained in an event buffer.
Returned by EventBuffer::steps.
Implementations
Sourceimpl<'buf, S: EngineSpec> EventBufferSteps<'buf, S>
impl<'buf, S: EngineSpec> EventBufferSteps<'buf, S>
Sourcepub fn as_slice(&self) -> &[(StepKey, &'buf EventBufferStepData<S>)]
pub fn as_slice(&self) -> &[(StepKey, &'buf EventBufferStepData<S>)]
Returns the list of steps in the event buffer.
Sourcepub fn summarize(&self) -> IndexMap<ExecutionUuid, ExecutionSummary>
pub fn summarize(&self) -> IndexMap<ExecutionUuid, ExecutionSummary>
Summarizes the current state of all known executions, keyed by execution ID.
Values are returned as an IndexMap, in order of when execution IDs
were first defined.