pub enum StepProgress<S: EngineSpec> {
Progress {
progress: Option<ProgressCounter>,
metadata: S::ProgressMetadata,
},
Reset {
metadata: S::ProgressMetadata,
message: Cow<'static, str>,
},
Retry {
message: Cow<'static, str>,
},
}Variants
Progress
A step has progressed.
Fields

progress: Option<ProgressCounter>Current progress.

metadata: S::ProgressMetadataMetadata associated with progress.
Reset
Progress was reset: typically, the step failed along one path, and the step is now trying a different path.
For example, downloading from one peer failed and we’ve moved to the next peer.
Fields

metadata: S::ProgressMetadataMetadata associated with the reset.
Retry
The step is being retried from the beginning.
Implementations
Sourceimpl<S: EngineSpec> StepProgress<S>
impl<S: EngineSpec> StepProgress<S>
Sourcepub fn with_current_and_total(
current: u64,
total: u64,
units: impl Into<ProgressUnits>,
metadata: S::ProgressMetadata,
) -> Self
pub fn with_current_and_total( current: u64, total: u64, units: impl Into<ProgressUnits>, metadata: S::ProgressMetadata, ) -> Self
Creates a new progress message with current and total values.
Sourcepub fn with_current(
current: u64,
units: impl Into<ProgressUnits>,
metadata: S::ProgressMetadata,
) -> Self
pub fn with_current( current: u64, units: impl Into<ProgressUnits>, metadata: S::ProgressMetadata, ) -> Self
Creates a new progress message with a current value.
Sourcepub fn progress(metadata: S::ProgressMetadata) -> Self
pub fn progress(metadata: S::ProgressMetadata) -> Self
Creates a new progress message without either current or total values.