pub struct StepEvent<S: EngineSpec> {
pub spec: String,
pub execution_id: ExecutionUuid,
pub event_index: usize,
pub total_elapsed: Duration,
pub kind: StepEventKind<S>,
}Fields
spec: StringThe specification that this event belongs to.
This is typically the name of the type S for which EngineSpec is
implemented.
This can be used along with Self::from_generic to identify which
specification to deserialize generic metadata against. For example:
if event.spec == "MySpec" {
// event is likely generated from a MySpec engine.
let event = Event::<MySpec>::from_generic(event)?;
// ...
}execution_id: ExecutionUuidThe execution ID.
event_index: usizeA monotonically increasing index for this StepEvent.
total_elapsed: DurationTotal time elapsed since the start of execution.
kind: StepEventKind<S>The kind of event this is.
Implementations
Sourceimpl<S: EngineSpec> StepEvent<S>
impl<S: EngineSpec> StepEvent<S>
Sourcepub fn progress_event(&self) -> Option<ProgressEvent<S>>
pub fn progress_event(&self) -> Option<ProgressEvent<S>>
Returns a progress event associated with this step event, if any.
Some step events have an implicit progress event of kind
ProgressEventKind::WaitingForProgress associated with them. This
causes those step events to generate progress events.
Sourcepub fn leaf_execution_id(&self) -> ExecutionUuid
pub fn leaf_execution_id(&self) -> ExecutionUuid
Returns the execution ID for the leaf event, recursing into nested events if necessary.
Sourcepub fn leaf_event_index(&self) -> usize
pub fn leaf_event_index(&self) -> usize
Returns the event index for the leaf event, recursing into nested events if necessary.
Sourcepub fn from_generic(
value: StepEvent<GenericSpec>,
) -> Result<Self, ConvertGenericError>
pub fn from_generic( value: StepEvent<GenericSpec>, ) -> Result<Self, ConvertGenericError>
Converts a generic version into self.
This version can be used to convert a generic type into a more concrete form.
Sourcepub fn into_generic(self) -> StepEvent<GenericSpec>
pub fn into_generic(self) -> StepEvent<GenericSpec>
Converts self into its generic version.
This version can be used to share data across different kinds of engines.
If any of the data in self fails to serialize to a
serde_json::Value, it will be replaced with
serde_json::Value::Null. Since serde_json::Value represents
an arbitrary JSON value, such data would have failed to serialize
anyway.