Structs
- Generic
Spec - A fully generic step specification where all metadata is
serde_json::Valueand errors areSerializableError. - Serializable
Error - A serializable representation of an error chain.
- Serializable
Error Sources - The sources of a serializable error as an iterator.
Traits
- AsError
- Trait that abstracts over concrete errors and
anyhow::Error. - Engine
Spec - A specification for an
UpdateEngine. - Json
Schema Engine Spec schemars08 - A trait that requires and provides JSON Schema information for an
EngineSpec.
Functions
- merge_
anyhow_ list - A temporary hack to convert a list of anyhow errors into a single
anyhow::Error. If no errors are provided, panic (this should be handled at a higher level).